@@ -1171,7 +1171,7 @@ phase5_get (token_ty *tp)
                 }
               buffer[bufpos++] = c;
               c = phase4_getc ();
-              if (c != '+' || c != '-')
+              if (c != '+' && c != '-')
                 {
                   phase4_ungetc (c);
                   break;
